@@ -1,15 +1,13 @@
 #
 # This file is part of MooseX-Attribute-Chained
 #
-# This software is copyright (c) 2012 by Moritz Onken.
+# This software is copyright (c) 2016 by Tom Hukins.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
 package MooseX::ChainedAccessors::Accessor;
-{
-  $MooseX::ChainedAccessors::Accessor::VERSION = '1.0.1';
-}
+$MooseX::ChainedAccessors::Accessor::VERSION = '1.0.2';
 # ABSTRACT: DEPRECATED
 use strict;
 use warnings;
@@ -21,15 +19,18 @@ sub _inline_post_body {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::ChainedAccessors::Accessor - DEPRECATED
 
 =head1 VERSION
 
-version 1.0.1
+version 1.0.2
 
 =head1 AUTHORS
 
@@ -37,6 +38,10 @@ version 1.0.1
 
 =item *
 
+Tom Hukins <tom@eborcom.com>
+
+=item *
+
 Moritz Onken <onken@netcubed.de>
 
 =item *
@@ -47,10 +52,9 @@ David McLaughlin <david@dmclaughlin.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Moritz Onken.
+This software is copyright (c) 2016 by Tom Hukins.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
